pespin has uploaded this change for review. ( 
https://gerrit.osmocom.org/c/osmo-pcu/+/32381 )


Change subject: tbf_dl: Avoid attempt scheduling DL ACK/NACK in TS != CTRL TS
......................................................................

tbf_dl: Avoid attempt scheduling DL ACK/NACK in TS != CTRL TS

Change-Id: I80cddc80f23992fd86637980f9e2bfc00a50e04e
---
M src/tbf_dl.cpp
1 file changed, 12 insertions(+), 2 deletions(-)



  git pull ssh://gerrit.osmocom.org:29418/osmo-pcu refs/changes/81/32381/1

diff --git a/src/tbf_dl.cpp b/src/tbf_dl.cpp
index 390d0ae..17b6a3a 100644
--- a/src/tbf_dl.cpp
+++ b/src/tbf_dl.cpp
@@ -799,8 +799,9 @@
                m_last_dl_poll_fn = fn;

        /* poll after POLL_ACK_AFTER_FRAMES frames, or when final block is tx or
-        * when last polled DL ACK/NACK was lost. */
-       if (need_poll_for_dl_ack_nack()) {
+        * when last polled DL ACK/NACK was lost. Always do so in the control 
TS. */
+       if (tbf_is_control_ts(dl_tbf_as_tbf(this), pdch) &&
+           need_poll_for_dl_ack_nack()) {
                if (m_dl_ack_requested) {
                        LOGPTBFDL(this, LOGL_DEBUG,
                                  "Scheduling Ack/Nack polling, because it was 
requested explicitly "

--
To view, visit https://gerrit.osmocom.org/c/osmo-pcu/+/32381
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-pcu
Gerrit-Branch: master
Gerrit-Change-Id: I80cddc80f23992fd86637980f9e2bfc00a50e04e
Gerrit-Change-Number: 32381
Gerrit-PatchSet: 1
Gerrit-Owner: pespin <[email protected]>
Gerrit-MessageType: newchange

Reply via email to